@@ -20,18 +20,6 @@ class IVarnishPurgerSettingsSchema(interface.Interface):
                            description=_(u"Varnish host address in format: hostname:port_number"),
                            default=u'localhost:6081',
                            required=False)
-    
-    purging_sites = Text(title=_(u'Purging domains'),
-                           description=_(u"Enter each domain in separate line in format: domain_name:port_number"),
-                           default=u'localhost:80',
-                           required=False)
-    
-    home_page_path = TextLine(title=_(u'Homepage path'),
-                           description=_(u"Path for homepage object"\
-                                         u"(leave blank if the plonesite is a homepage object)"),
-                           default=u'',
-                           required=False)
-
 
 class VarnishPurgerSettingsControlPanelAdapter(SiteControlPanelAdapter):
     """Adapter required for control-panel."""
@@ -39,8 +27,6 @@ class VarnishPurgerSettingsControlPanelAdapter(SiteControlPanelAdapter):
     implements(IVarnishPurgerSettingsSchema)
 
     varnish_host = ProxyFieldProperty(IVarnishPurgerSettingsSchema['varnish_host'])
-    purging_sites = ProxyFieldProperty(IVarnishPurgerSettingsSchema['purging_sites'])
-    home_page_path = ProxyFieldProperty(IVarnishPurgerSettingsSchema['home_page_path'])
 
 class VarnishPurgerSettingsForm(ControlPanelForm):
     """Static export form"""
